@@ -7,7 +7,8 @@ zeta.fun <- function(x)
     k = 8
     B = c(1/6, -1/30, 1/42, -1/30, 5/66, -691/2730, 7/6, -3617/510)
     ans = 0
-    for (ii in 1:(a - 1)) ans = ans + 1/ii^x
+#    for (ii in 1:(a - 1)) ans = ans + 1/ii^x
+	ans = sum(1/c(1:(a - 1))^x)
     ans = ans + 1/((x - 1) * a^(x - 1)) + 1/(2 * a^x)
     term = (x/2)/a^(x + 1)
     ans = ans + term * B[1]
